  /******************************************************************************
  * @file   PT32X003_adc.h
  * @author  ӦÿŶ
  * @version V1.0.0
  * @date    2022/5/27
  * @brief   This file contains all the functions prototypes for the ADC firmware library
  *          
  ******************************************************************************
  * @attention
  *
  *
  *****************************************************************************/

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef PT32X003_ADC_H
#define PT32X003_ADC_H

#ifdef __cplusplus
extern "C" {
#endif

/* Includes ------------------------------------------------------------------*/
#include "PT32X003.h"


/** @addtogroup ADC
  * @{
  */


/* Exported types ------------------------------------------------------------*/

/** @brief  ADC Init structure definition **/



typedef struct
{
	u32 ADC_MODE;
	u32 ADC_TIMS;                                             
	u32 ADC_ALIGN;	
	u32 ADC_Channel;        
    u32 ADC_AVG;
    u32 ADC_VREFS;
    u32 ADC_PSC;
	
} ADC_InitTypeDef;



/* Exported constants --------------------------------------------------------*/

/** @defgroup ADC_MODE_SEL **/
#define IS_ADC_ALL_PERIPH(PERIPH)	((PERIPH) == ADC)

#define ADC_MODE_Single          ADC_CR_MODE_Single
#define ADC_MODE_Continuous      ADC_CR_MODE_Continuous
#define ADC_MODE_TIM            ADC_CR_MODE_TIM
#define IS_ADC_MODE_SEL(SEL)	(((SEL) == ADC_MODE_Single)   ||\
                                ((SEL) == ADC_MODE_Continuous)   ||\
								((SEL) == ADC_MODE_TIM))




/** @defgroup ADC_TIMS_SEL **/
#define ADC_TIMS_TIM1           ADC_CR_TIMS_TIM1
#define ADC_TIMS_TIM2           ADC_CR_TIMS_TIM2
#define ADC_TIMS_TIM3           ADC_CR_TIMS_TIM3
#define IS_ADC_TIMS_SEL(SEL)	(((SEL) == ADC_TIMS_TIM1)||\
								((SEL) == ADC_TIMS_TIM2)||\
								((SEL) == ADC_TIMS_TIM3))


///** @defgroup ADC_CAL_SEL **/
//#define IS_ADC_CAL_SEL(SEL)	    (((SEL) == ADC_CR_CAL_Normal)||\
//								((SEL) == ADC_CR_CAL_Calibration))
                                
 /** @defgroup ADC_ALIGN_SEL **/
#define ADC_DataAlign_Right         ADC_CR_ALIGN_Right
#define ADC_DataAlign_Left          ADC_CR_ALIGN_Left
#define IS_ADC_ALIGN_SEL(SEL) 	(((SEL) == ADC_DataAlign_Right) || \
							((SEL) == ADC_DataAlign_Left))
                                
/** @defgroup ADC_channels **/

#define ADC_Channel_0  ADC_CR_CHS_0             
#define ADC_Channel_1  ADC_CR_CHS_1                  
#define	ADC_Channel_2  ADC_CR_CHS_2                
#define	ADC_Channel_3  ADC_CR_CHS_3     
#define ADC_Channel_4  ADC_CR_CHS_4
#define ADC_Channel_5  ADC_CR_CHS_5
#define ADC_Channel_6  ADC_CR_CHS_6
#define ADC_Channel_7  ADC_CR_CHS_7    
#define ADC_Channel_8  ADC_CR_CHS_8
#define ADC_Channel_9  ADC_CR_CHS_9
#define ADC_Channel_10 ADC_CR_CHS_10
#define ADC_Channel_11 ADC_CR_CHS_11
#define ADC_Channel_12 ADC_CR_CHS_12
#define ADC_Channel_13 ADC_CR_CHS_13
#define ADC_Channel_14 ADC_CR_CHS_14
#define IS_ADC_CHS_SEL(SEL)		(((SEL) == ADC_Channel_0) ||\
								((SEL) == ADC_Channel_1) ||\
								((SEL) == ADC_Channel_2) ||\
 								((SEL) == ADC_Channel_3) ||\
								((SEL) == ADC_Channel_4) ||\
								((SEL) == ADC_Channel_5) ||\
								((SEL) == ADC_Channel_6) ||\
								((SEL) == ADC_Channel_7) ||\
								((SEL) == ADC_Channel_8) ||\
								((SEL) == ADC_Channel_9) ||\
                                ((SEL) == ADC_Channel_10) ||\
                                ((SEL) == ADC_Channel_11) ||\
                                ((SEL) == ADC_Channel_12) ||\
                                ((SEL) == ADC_Channel_13) ||\
								((SEL) == ADC_Channel_14)) 
                                

                                    
/** @defgroup ADC_AVG_SEL **/
#define ADC_AVG_Realtim         ADC_CR_AVG_Realtime
#define ADC_AVG_Average         ADC_CR_AVG_Average
#define IS_ADC_AVG_SEL(SEL)	    (((SEL) == ADC_AVG_Realtim)||\
                                    ((SEL) == ADC_AVG_Average))
                                    
/** @defgroup ADC_VREFS_SEL **/
#define ADC_VREFS_VDD       ADC_CR_VREFS_VDD
#define ADC_VREFS_PD6       ADC_CR_VREFS_PD6
#define IS_ADC_VREFS_SEL(SEL)	    (((SEL) == ADC_VREFS_VDD)||\
                                    ((SEL) == ADC_VREFS_PD6))
                                    
                                    
		
                                    
/** @defgroup IS_ADC_SMP_SEL **/                                    
#define IS_ADC_SMP_SEL(Value)	      (((Value) > 2) && ((Value) < 256))	
                                    
/** @defgroup ADC_PSC_SEL **/
#define IS_ADC_PSC_SEL(Value)		((Value) <= 0x7F)	

/** @defgroup ADC_UDT_SEL **/
#define IS_ADC_AVGT_SEL(Value)   ((Value) > 0 &&(Value) <= 0x80)	

										





#define ADC_FLAG_EOCIE            ADC_CR_EOCIE
#define ADC_FLAG_RDY              ADC_SR_RDY                     
#define ADC_FLAG_EOC              ADC_SR_EOC                        


#define IS_ADC_GET_FLAG(FLAG)	(((FLAG) == ADC_FLAG_RDY)   || \
								((FLAG) == ADC_FLAG_EOC))
                                
#define IS_ADC_CLEAR_FLAG(FLAG) (((FLAG) != (u32)RESET) && (((FLAG) & 0xFFFFFFFC) == (u32)RESET))



/* Exported macro ------------------------------------------------------------*/
/* Exported functions ------------------------------------------------------- */
void ADC_DeInit(ADC_TypeDef* ADCx);
void ADC_Init(ADC_TypeDef* ADCx, ADC_InitTypeDef* ADC_InitStruct);
void ADC_StructInit(ADC_InitTypeDef* ADC_InitStruct);
void ADC_Cmd(ADC_TypeDef* ADCx, FunctionalState NewState);
void ADC_ChannelConfig(ADC_TypeDef* ADCx, u32 ADC_Channel);
void ADC_ConversionConfig(ADC_TypeDef* ADCx,FunctionalState NewState);
u16 ADC_GetConversionValue(ADC_TypeDef* ADCx);
void ADC_ITConfig(ADC_TypeDef* ADCx,FunctionalState NewState);
FlagStatus ADC_GetFlagStatus(ADC_TypeDef* ADCx, u32 ADC_FLAG);
void ADC_ClearFlag(ADC_TypeDef* ADCx, u32 ADC_FLAG);
void ADC_SetSampleTime(ADC_TypeDef* ADCx, u32 SAM_Time);
void ADC_SetAverageNumber(ADC_TypeDef* ADCx, u32 Number);
/**
  * @}
  */
  
#ifdef __cplusplus
}
#endif

#endif


