 /******************************************************************************
  * @file    PT32X003_ifmc.h
  * @author  ӦÿŶ
  * @version V1.0.0
  * @date    2022/5/27
  * @brief    This file contains all the functions prototypes for the FLASH firmware library.
  *          
  ******************************************************************************
  * @attention
  *
  *
  *****************************************************************************/

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef PT32X003_IFMC_H
#define PT32X003_IFMC_H

#ifdef __cplusplus
 extern "C" {
#endif

/* Includes ------------------------------------------------------------------*/
#include "PT32X003.h"


/** @addtogroup FLASH
  * @{
  */

/* Exported types ------------------------------------------------------------*/


/**  @brief  FLASH Status **/ 
typedef enum
{	
	IFMC_WriteOver=1,
	IFMC_ProgramOver,
	IFMC_ChipEraseOver,
	IFMC_Busy,
	IFMC_CommandError,
	IFMC_KeyError,
	IFMC_AddrError,
	IFMC_Complete,
	IFMC_TimeOut
}FLASH_Status;

/* Exported constants --------------------------------------------------------*/

/** @defgroup IS_FLASH_WAIT_SEL  **/ 
#define  IFMC_LatencyCycle_0			((u32)0x00000000)	      /* 0ڵȴ*/
#define  IFMC_LatencyCycle_1			((u32)0x00000020)	      /* 1ڵȴ*/
#define  IFMC_LatencyCycle_2			((u32)0x00000040)	      /* 2ڵȴ*/
#define  IFMC_LatencyCycle_3			((u32)0x00000060)	      /* 3ڵȴ*/	
#define  IFMC_LatencyCycle_4			((u32)0x00000080)	      /* 4ڵȴ*/	
#define  IFMC_LatencyCycle_5			((u32)0x000000A0)	      /* 5ڵȴ*/	
#define  IFMC_LatencyCycle_6			((u32)0x000000C0)	      /* 6ڵȴ*/
#define  IFMC_LatencyCycle_7			((u32)0x000000E0)	      /* 7ڵȴ*/
#define IS_FLASH_WAIT_SEL(SEL)	(((SEL) == IFMC_LatencyCycle_0) || \
                                   			((SEL) == IFMC_LatencyCycle_1)|| \
                                   			((SEL) == IFMC_LatencyCycle_2)|| \
                                   			((SEL) == IFMC_LatencyCycle_3)|| \
                                   			((SEL) == IFMC_LatencyCycle_4)|| \
                                   			((SEL) == IFMC_LatencyCycle_5)|| \
                                   			((SEL) == IFMC_LatencyCycle_6)|| \
                                   			((SEL) == IFMC_LatencyCycle_7))
                                   
/** @defgroup FLASH_Interrupts  **/ 
#define IS_FLASH_IT(IT) ((IT<= 0x7F) && (IT!=0x08))

#define IS_FLASH_PSC_Value(Value) ((Value< 64) )

/** @defgroup FLASH_Address  **/ 
#define FLASH_PAGE_SIZE    ((u16)0x200)	 /*!< 512B */
#define MAINCODE_START_ADDR  ((u32)0x00000000)

#if defined(FLASH_SIZE_16K)
	#if defined(BOOT_SIZE_3K5)
		#define MAINCODE_END_ADDR    ((u32)0x00003FFF)
	#elif defined(BOOT_SIZE_2K5)
		#define MAINCODE_END_ADDR    ((u32)0x000043FF)
	#elif defined(BOOT_SIZE_1K5)
		#define MAINCODE_END_ADDR    ((u32)0x000047FF)
	#else
		#define MAINCODE_END_ADDR    ((u32)0x00004DFF)
	#endif
#elif defined(FLASH_SIZE_32K)
	#if defined(BOOT_SIZE_3K5)
		#define MAINCODE_END_ADDR    ((u32)0x00006FFF)
	#elif defined(BOOT_SIZE_2K5)
		#define MAINCODE_END_ADDR    ((u32)0x000073FF)
	#elif defined(BOOT_SIZE_1K5)
		#define MAINCODE_END_ADDR    ((u32)0x000077FF)
	#else
		#define MAINCODE_END_ADDR    ((u32)0x00007DFF)
	#endif
#else
	#define MAINCODE_END_ADDR    ((u32)0x00002FFF)
#endif

#define IS_FLASH_PROGRAM_ADDRESS(ADDRESS)   (((ADDRESS) <= MAINCODE_END_ADDR))


/** @defgroup IS_FLASH_SR_SEL & GET  **/ 
#define  IFMC_FLAG_WOV	IFMC_SR_WOV	/* д */
#define  IFMC_FLAG_POV	IFMC_SR_POV		/* ҳ */
#define  IFMC_FLAG_COV	IFMC_SR_COV	/* ȫƬ */
#define  IFMC_FLAG_BUSY	IFMC_SR_BUSY	/* IFMCæ־ */
#define  IFMC_FLAG_CERR	IFMC_SR_CERR	/* IFMC־ */
#define  IFMC_FLAG_KERR	IFMC_SR_KERR	/* IFMC־ */
#define  IFMC_FLAG_AERR	IFMC_SR_AERR	/* IFMCַ־ */
#define IS_FLASH_SR_SEL(SEL)	((((SEL) & (u16)0xff00) == 0) && ((SEL) != (u16)0x00))
#define IS_FLASH_SR_GET(GET)	(((GET) == IFMC_FLAG_WOV) || \
								((GET) == IFMC_FLAG_POV) || \
								((GET) == IFMC_FLAG_COV) || \
								((GET) == IFMC_FLAG_BUSY) || \
								((GET) == IFMC_FLAG_CERR) || \
								((GET) == IFMC_FLAG_KERR) || \
								((GET) == IFMC_FLAG_AERR))
                                  
/** @defgroup FLASH_Timeout_definition  **/ 
#define FLASH_ER_PRG_TIMEOUT	((u32)0x000B0000)

/** @brief  FLASH Operation Commands **/ 
#define FLASH_OPCMD_PRO   ((u32)0x00000000) 
#define FLASH_OPMOD_RE    ((u32)0x00000000) 
#define FLASH_OPCMD_PERA   IFMC_CR_CMD_PERA
#define FLASH_OPCMD_MERA   IFMC_CR_CMD_MERA
#define FLASH_OPMOD_WR    IFMC_CR_MODE
#define FLASH_OPSTR_STRT  IFMC_CR_START


/* Exported macro ------------------------------------------------------------*/
/* Exported functions ------------------------------------------------------- */
void IFMC_SetLatency(u32 FLASH_Latency);
void IFMC_SetPrescaler(u8 Prescaler);
FLASH_Status IFMC_GetFlashStatus(void);
FLASH_Status IFMC_WaitForLastFlashOperation(u32 Timeout);

FLASH_Status IFMC_ErasePage(u32 Page_Address);
FLASH_Status IFMC_EraseAllPages(void);
FLASH_Status IFMC_ProgramWord(u32 Address, u32 Data);

u32 IFMC_ReadWord(u32 Address);
u16 IFMC_ReadHalfWord(u32 Address);
u8 IFMC_ReadByte(u32 Address);

void IFMC_ITConfig(u32 FLASH_IT, FunctionalState NewState);
FlagStatus IFMC_GetFlagStatus(u32 FLASH_FLAG);
void IFMC_ClearFlag(u32 FLASH_FLAG);
RemapStatus IFMC_GetBootStatus(void);
ProtectStatus IFMC_GetReadProtectStatus(void);

/**
  * @}
  */

  
#ifdef __cplusplus
}
#endif

#endif 
