/******************************************************************************
* @file    PT32X003_pwm.h
* @author  ӦÿŶ
* @version V1.0.0
* @date    2022/5/27
* @brief    This file contains all the functions prototypes for the PWM firmware library.
*
******************************************************************************
* @attention
*
*
*****************************************************************************/


/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef PT32X003_PWM_H
#define PT32X003_PWM_H

#ifdef __cplusplus
extern "C" {
#endif

/* Includes ------------------------------------------------------------------*/
#include "PT32X003.h"

/** @addtogroup PWM
  * @{
  */

/* Exported types ------------------------------------------------------------*/


/** @brief Definition of PWM timebase init structure. **/
typedef struct
{
	u32	PWM_Period;         /*!< Period (Value for MR0 register)             */
	u32	PWM_ClockSel;              /*!< Counting Clock select:HCLK or PCLK          */
	u32	PWM_Prescaler;             /*!< Prescaler (Value for PR register)           */
	u32	PWM_CounterMode;           /*!< Counter mode up-counting or down-counting   */
} PWM_TimeBaseInitTypeDef;


/** @brief Enumeration of PWM channel. **/
typedef enum
{
	PWM_Channel_1 = 0,                /*!< PWM channel 1 */
	PWM_Channel_2,                    /*!< PWM channel 2 */
	PWM_Channel_3,                    /*!< PWM channel 3 */
	PWM_Channel_4                     /*!< PWM channel 4 */
} PWM_CH_Enum;

/** @brief Enumeration of PWM channel output mode. **/
typedef enum
{
	PWM_OCMode_Timing   = 0,                    /*!< PWM channel no output */
	PWM_OCMode_PWM1,                      /*!< PWM channel output high when tc <= compare value,output low when tc > compare value */
	PWM_OCMode_PWM2,                      /*!< PWM channel output low when tc <= compare value,output high when tc > compare value */
	PWM_OCMode_Toggle ,                      /*!< PWM channel output reverse when tc match compare value */
    PWM_OCMode_Valid,                          /*!< ЧƽTIM1_CNT=TIM1_OCRxʱOC1REFЧƽ */
    PWM_OCMode_Invalid,                         /*!< ЧƽTIM1_CNT=TIM1_OCRxʱOC1REFЧƽ */
    PWM_OCMode_ForcedActionActive,                 /*!< ǿЧƽ */
    PWM_OCMode_ForcedActionInActive              /* !< ǿЧƽ */   
} PWM_OM_Enum;

/** @brief Definition of PWM channel output init structure. **/
typedef struct
{
	PWM_CH_Enum	PWM_Channel;              /*!< Channel selection refer to \ref PWM_CH_Enum */
	PWM_OM_Enum	PWM_OCMode;           /*!< Channel output mode selection refer to \ref MCTM_OM_Enum */
	u32	PWM_OutputNState;             /*!< CHxN output enble or disable refer to */
	u16	PWM_Pulse;         /*!< Value for MRx register */
	u32	PWM_OCPolarity;
	u32	PWM_OCNPolarity;
	u32	PWM_OCIdleState; 
	u32	PWM_OCNIdleState; 
	u16    PWM_DeathTime;            /*!< Value for DT register */
} PWM_OCInitTypeDef;


/** @brief Definition of PWM channel Capture init structure. **/
typedef struct
{
	PWM_CH_Enum	PWM_Channel;              /*!< Channel selection refer to \ref PWM_CH_Enum */
	u16          PWM_ICRstCount;           /*!< Channel Capture mode selection*/
	u16          PWM_ICPolarity;	 
} PWM_ICInitTypeDef;

typedef struct
{
  u32 PWM_Break;  
  u32 PWM_BreakPolarity;  
  u32 PWM_BreakSource;
  u32 PWM_BreakControl;
} PWM_BKIInitTypeDef;


/* Exported constants --------------------------------------------------------*/
#define IS_PWM_ALL_PERIPH(PERIPH)		((PERIPH) == TIM1)

#define IS_PWM_REPEATTIME(TIMES)             ((TIMES) <= 0xF)

#define IS_PWM_COUNTER_RELOAD(RELOADVALUE)   ((RELOADVALUE) <= 0xFFFF)

#define IS_PWM_COUNTER_VALUE(COUNTERVALUE)   ((COUNTERVALUE) <= 0xFFFF)


#define PWM_ClockSel_PCLK           TIM1_CR1_CLKS_PCLK
#define PWM_ClockSel_SYSCLK         TIM1_CR1_CLKS_SYS
#define IS_PWM_CLOCKSEL(SEL)	(((SEL) == PWM_ClockSel_PCLK) || \
								((SEL) == PWM_ClockSel_SYSCLK))




#define PWM_Break_Enable        TIM1_BDTR_BKE_ENABLE
#define PWM_Break_Disable       TIM1_BDTR_BKE_DISABLE                              			
#define IS_PWM_BKI_SET(SET)	(((SET) == PWM_Break_Disable) || \
                            ((SET) == PWM_Break_Enable))
                            
                            
#define PWM_BreakPolarity_High        TIM1_BDTR_BKP_HIGH
#define PWM_BreakPolarity_Low         TIM1_BDTR_BKP_LOW
#define IS_PWM_BKIPol_SET(SET)	(((SET) == PWM_BreakPolarity_High) || \
                                 ((SET) == PWM_BreakPolarity_Low))
                                                                                



#define PWM_BreakSource_BKIN             TIM1_BDTR_BKS_TIM1_BKIN
#define PWM_BreakSource_LockUp           TIM1_BDTR_BKS_LOCKUP    
#define PWM_BreakSource_Soft           TIM1_BDTR_BKS_SOFT    
#define IS_PWM_BKISource_SEL(SEL)	(((SEL) == PWM_BreakSource_BKIN) || \
									((SEL) == PWM_BreakSource_LockUp)|| \
									((SEL) == PWM_BreakSource_Soft))


#define PWM_BreakControl_Idle             TIM1_BDTR_BKTS_DISABLE
#define PWM_BreakControl_Close           TIM1_BDTR_BKTS_ENABLE    
#define IS_PWM_BKIControl_SET(SET)	(((SET) == PWM_BreakControl_Idle) || \
                                    ((SET) == PWM_BreakControl_Close))
                                                
#define IS_PWM_PRESCALER(PRESCALER)           ((PRESCALER)<= 0xFFFF)


                                    

 

#define PWM_CounterMode_Up                  (TIM1_CR1_CMS_EDGE | TIM1_CR1_DIR_UP)
#define PWM_CounterMode_Down                (TIM1_CR1_CMS_EDGE | TIM1_CR1_DIR_DOWN)
#define PWM_CounterMode_CenterAligned       TIM1_CR1_CMS_CENTER
#define IS_PWM_Conter_Mode(MODE)    (((MODE) == PWM_CounterMode_Up) || \
                                     ((MODE) == PWM_CounterMode_Down) || \
                                       ((MODE) == PWM_CounterMode_CenterAligned))

#define PWM_EventSource_Update	TIM1_CR1_UG
#define PWM_EventSource_Break	TIM1_BDTR_SWBK
#define IS_PWM_EVENT_SOURCE(SEL) (((SEL) == PWM_EventSource_Update) || \
									((SEL) == PWM_EventSource_Break))

#define IS_PWM_CHCHANNEL(SEL)	(((SEL) == PWM_Channel_1) || \
								((SEL) == PWM_Channel_2) ||\
								((SEL) == PWM_Channel_3) || \
								((SEL) == PWM_Channel_4))

#define IS_PWM_OM(MODE)	(((MODE) == PWM_OCMode_Timing)  || \
							((MODE) == PWM_OCMode_PWM1) || \
							((MODE) == PWM_OCMode_PWM2) || \
							((MODE) == PWM_OCMode_Toggle) || \
                            ((MODE) == PWM_OCMode_Valid) || \
                            ((MODE) == PWM_OCMode_Invalid) || \
                            ((MODE) == PWM_OCMode_ForcedActionActive) || \
                            ((MODE) == PWM_OCMode_ForcedActionInActive) )

	
#define PWM_ICRstCount_Disable 	((u16)0x0000)
#define PWM_ICRstCount_Enable	TIM1_CAPR_IC1RC
#define IS_PWM_RC_SEL(SEL)	(((SEL) == PWM_ICRstCount_Disable)  || \
							((SEL) == PWM_ICRstCount_Enable))

#define PWM_ICPolarity_Rising		((u16)0x0001)
#define PWM_ICPolarity_Falling		((u16)0x0002)
#define PWM_ICPolarity_BothEdge		((u16)0x0003)
#define IS_PWM_POLARITY_SEL(SEL)	(((SEL) == PWM_ICPolarity_Rising)  || \
									((SEL) == PWM_ICPolarity_Falling) || \
									((SEL) == PWM_ICPolarity_BothEdge))

#define  PWM_OutputNState_Disable           ((u32)0x00000000)      /*!< PWM channel_N disable */
#define  PWM_OutputNState_Enable             TIM1_OCMR_OC1NE           /*!< PWM channel_N enable */
#define IS_PWM_CHNCTL(CHNCTL)	(((CHNCTL) == PWM_OutputNState_Disable) || \
 								((CHNCTL) == PWM_OutputNState_Enable))

#define PWM_OCPolarity_High	((u16)0x0000)
#define PWM_OCPolarity_Low	TIM1_OCPR_OC1P
#define IS_PWM_OC_POLARITY(POLARITY)	(((POLARITY) == PWM_OCPolarity_High) || \
                                      					((POLARITY) == PWM_OCPolarity_Low))
                                      					
#define PWM_OCNPolarity_High	((u16)0x0000)
#define PWM_OCNPolarity_Low	TIM1_OCPR_OC1NP
#define IS_PWM_OCN_POLARITY(POLARITY) (((POLARITY) == PWM_OCNPolarity_High) || \
										((POLARITY) == PWM_OCNPolarity_Low))

#define PWM_OCIdleState_Low		((u16)0x0000)
#define PWM_OCIdleState_High		TIM1_OCMR_OIS1
#define IS_PWM_OCIDLE_STATE(STATE) (((STATE) == PWM_OCIdleState_Low) || \
									((STATE) == PWM_OCIdleState_High))

#define PWM_OCNIdleState_Low		((u16)0x0000)
#define PWM_OCNIdleState_High		TIM1_OCMR_OIS1N
#define IS_PWM_OCNIDLE_STATE(STATE)	(((STATE) == PWM_OCNIdleState_Low) || \
										((STATE) == PWM_OCNIdleState_High))


#define IS_PWM_COMPAREVALUE(VALUE)           ((VALUE) <= 0xFFFF)

#define IS_PWM_DEATHTIME(VALUE)              ((VALUE) <= 0xFFF)

#define PWM_IE_ARI	TIM1_CR2_ARI
#define PWM_IE_OC1	TIM1_CR2_OC1I
#define PWM_IE_OC2	TIM1_CR2_OC2I
#define PWM_IE_OC3	TIM1_CR2_OC3I
#define PWM_IE_OC4	TIM1_CR2_OC4I
#define PWM_IE_IC1  ((u32)0x00000020)  //TIM1_CR2_OC3ITIM1_CR2_IC1Iͬ
#define PWM_IE_IC2	TIM1_CAPR_IC2I
#define PWM_IE_IC3	TIM1_CAPR_IC3I
#define PWM_IE_IC4	TIM1_CAPR_IC4I
#define PWM_IE_BK	TIM1_BDTR_BKI

#define IS_PWM_IE_GET(SEL)	(((SEL) == PWM_IE_ARI)  || \
							((SEL) == PWM_IE_OC1)  || \
							((SEL) == PWM_IE_OC2)  || \
							((SEL) == PWM_IE_OC3)  || \
							((SEL) == PWM_IE_OC4)  || \
							((SEL) == PWM_IE_IC1)  || \
							((SEL) == PWM_IE_IC2)  || \
							((SEL) == PWM_IE_IC3)  || \
							((SEL) == PWM_IE_IC4)  || \
							((SEL) == PWM_IE_BK))

#define IS_PWM_FLAG_SET(SET) ((SET)  <= 0X3FFF)

#define PWM_FLAG_ARF          TIM1_SR_ARF
#define PWM_FLAG_OC1F         TIM1_SR_OC1F
#define PWM_FLAG_OC2F         TIM1_SR_OC2F
#define PWM_FLAG_OC3F         TIM1_SR_OC3F
#define PWM_FLAG_OC4F         TIM1_SR_OC4F
#define PWM_FLAG_IC1F         TIM1_SR_IC1F
#define PWM_FLAG_IC1R         TIM1_SR_IC1R
#define PWM_FLAG_IC2F         TIM1_SR_IC2F
#define PWM_FLAG_IC2R         TIM1_SR_IC2R
#define PWM_FLAG_IC3F         TIM1_SR_IC3F
#define PWM_FLAG_IC3R         TIM1_SR_IC3R
#define PWM_FLAG_IC4F         TIM1_SR_IC4F
#define PWM_FLAG_IC4R         TIM1_SR_IC4R
#define PWM_FLAG_BIF          TIM1_SR_BIF
#define PWM_FLAG_UIF          TIM1_SR_UIF


#define IS_PWM_FLAG_GET(SEL)   (((SEL) == PWM_FLAG_ARF)  || \
								((SEL) == PWM_FLAG_OC1F) || \
								((SEL) == PWM_FLAG_OC2F) || \
								((SEL) == PWM_FLAG_OC3F) || \
								((SEL) == PWM_FLAG_OC4F) || \
								((SEL) == PWM_FLAG_IC1F) || \
								((SEL) == PWM_FLAG_IC1R) || \
								((SEL) == PWM_FLAG_IC2F) || \
								((SEL) == PWM_FLAG_IC2R) || \
								((SEL) == PWM_FLAG_IC3F) || \
								((SEL) == PWM_FLAG_IC3R) || \
								((SEL) == PWM_FLAG_IC4F) || \
								((SEL) == PWM_FLAG_IC4R) || \
                                ((SEL) == PWM_FLAG_BIF)  || \
								((SEL) == PWM_FLAG_UIF))



/* Exported macro ------------------------------------------------------------*/
/* Exported functions ---------------------------------------------------------*/
void PMW_TimeBaseInit(TIM1_TypeDef* PWMx, PWM_TimeBaseInitTypeDef* TimeBaseInit);
void PWM_TimeBaseStructInit(PWM_TimeBaseInitTypeDef* TimeBaseInit);
void PWM_OCInit(TIM1_TypeDef* PWMx, PWM_OCInitTypeDef* OutInit);
void PWM_OCStructInit(PWM_OCInitTypeDef* PWM_OCInitStruct);
void PWM_ICInit(TIM1_TypeDef* PWMx, PWM_ICInitTypeDef* CapInit);
void PWM_ICStructInit(PWM_ICInitTypeDef* PWM_ICInitStruct);
void PWM_BKIConfig(TIM1_TypeDef* PWMx,PWM_BKIInitTypeDef* PWM_BKIInitStruct);
void PWM_BKIStructInit(PWM_BKIInitTypeDef* PWM_BKIInitStruct);

void PWM_ITRepeatConfig(TIM1_TypeDef* PWMx, u8 ITReload);
void PWM_PrescalerConfig(TIM1_TypeDef* PWMx, u16 Prescaler);
void PWM_SetAutoreload(TIM1_TypeDef* PWMx, u16 Reload);
void PWM_SetCounter(TIM1_TypeDef* PWMx, u16 Counter);
void PWM_CounterModeConfig(TIM1_TypeDef* PWMx, u32 CounterMode);
void PWM_GenerateEvent(TIM1_TypeDef* PWMx, u32 PWM_EventSource);
void PWM_Cmd(TIM1_TypeDef* PWMx, FunctionalState NewState);

void PWM_ITConfig(TIM1_TypeDef* PWMx, u32 PWM_INT, FunctionalState NewState);
void PWM_ClearFlag(TIM1_TypeDef* PWMx, u32 PWM_FLAG);
void PWM_SetCompare(TIM1_TypeDef* PWMx, u8 CHx, u16 Cmp);
FlagStatus PWM_GetFlagStatus(TIM1_TypeDef* PWMx, u32 PWM_FLAG);
u16 PWM_GetCapture(TIM1_TypeDef* PWMx, u8 CHx);
u16 PWM_GetCounter(TIM1_TypeDef* PWMx);
u16 PWM_GetPrescaler(TIM1_TypeDef* PWMx);
u8 PWM_GetITCounter(TIM1_TypeDef* PWMx);

/**
  * @}
  */

  
#ifdef __cplusplus
}
#endif

#endif


