/*********************************************************************************************************//**
 * @file    PT32X003_serial.c
 * @version V1.00
 * @date    07/10/2020
 * @brief   This file provides all the Low level serial routines for pangu01
 *************************************************************************************************************

 ************************************************************************************************************/

/* Includes ------------------------------------------------------------------------------------------------*/
#include "PT32X003.h"



/** @defgroup SERIAL SERIAL
  * @brief Serial related functions
  * @{
  */

/*********************************************************************************************************//**
 * @brief  Put char to UART.
 * @param  ch: The char put to UART.
 * @retval The char put to UART.
 ************************************************************************************************************/
u8 SERIAL_PutChar(u8 ch)
{
#ifdef UART_USED_UART0
	while((UART0->SR & UART_FLAG_TXF));
	UART0->DR = ch;
#else
	while((UART1->SR & UART_FLAG_TXF));
	UART1->DR = ch;
#endif
	return ch;
}

/*********************************************************************************************************//**
 * @brief  Get char from UART.
 * @retval The char got from UART.
 ************************************************************************************************************/
u8 SERIAL_GetChar(void)
{
#ifdef UART_USED_UART0
	while ((UART0->SR & 0x0001) == 0); // Wait if Receive Holding register is empty
	return (UART0->DR);
#else
	while ((UART1->SR & 0x0001) == 0); // Wait if Receive Holding register is empty
	return (UART1->DR);
#endif
}

/**
  * @}
  */


